@@ -206,19 +206,21 @@ dir_empty_p (const char * dirname)
     struct dirent * ent;
     int count = 0;
 
-    if (! (dir = opendir (dirname))) {
-	message (LOG_ERROR,
-		 "Cannot opendir(%s): %s\n",
-		 dirname, strerror(errno));
+    if (! (dir = opendir(dirname))) {
+	message(LOG_ERROR,
+		"Cannot opendir(%s): %s\n", dirname, strerror(errno));
 	return 0;
     }
-    while ((ent = readdir (dir))) {
-	if (((ent->d_name[0] == '.') && (ent->d_name[1] == '\0')) ||
-	    ((ent->d_name[1] == '.') && (ent->d_name[2] == '\0')))
+    while ((ent = readdir(dir))) {
+        if ((ent->d_name[0] == '.') && (
+                 (ent->d_name[1] == '\0') ||
+                 ((ent->d_name[1] == '.') && (ent->d_name[2] == '\0'))
+            )
+           )
 	    continue;
-	
 	count++;
     }
+    closedir(dir);
     return count != 0 ? 0 : 1;	/* #t when empty. */
 }
 
